.. -*- mode: ReST -*-

.. _glossary:

========
Glossary
========

.. contents::
   :local:

.. glossary::

   doot.toml
        The main config file.

   task.toml
        Files that provide :term:`taskspec`.


   taskspec
        A Toml Specification of a :term:`task`.
